@@ -26,6 +26,8 @@
  (special lop rop $inchar)
  (*expr wxxml-lbp wxxml-rbp))
 
+#+ccl (setf *print-circle* nil)
+
 ;;; Muffle compiler-notes globally
 #+sbcl (declaim (sb-ext:muffle-conditions sb-ext:compiler-note))
 (defmacro no-warning (form)
@@ -341,7 +343,7 @@
 (defprop $xi "<g>xi</g>" wxxmlword)
 (defprop $%omicron "<g>%omicron</g>" wxxmlword)
 (defprop $omicron "<g>omicron</g>" wxxmlword)
-(defprop $%pi "<g>%pi</g>" wxxmlword)
+(defprop $%pi "<s>%pi</s>" wxxmlword)
 (defprop $pi "<g>pi</g>" wxxmlword)
 (defprop $%rho "<g>%rho</g>" wxxmlword)
 (defprop $rho "<g>rho</g>" wxxmlword)
@@ -570,9 +572,15 @@
               (null (cdadr x)))
          (append l `("<fn><fnm>matrix</fnm><p><t>[</t><t>]</t></p></fn>") r))
         (t
-         (append l (if (find 'inference (car x))
-		       (list "<tb inference='t'>")
-		       (list "<tb>"))
+         (append l (cond
+		     ((find 'inference (car x))
+		      (list "<tb inference=\"true\">"))
+		     ((find 'special (car x))
+		      (list (format nil "<tb special=\"true\" rownames=~s colnames=~s>"
+				    (if (find 'rownames (car x)) "true" "false")
+				    (if (find 'colnames (car x)) "true" "false"))))
+		     (t
+		       (list "<tb>")))
                  (mapcan #'(lambda (y)
 			     (cond ((null (cdr y))
 				    (list "<mtr><mtd><mspace/></mtd></mtr>"))
@@ -839,13 +847,13 @@
   ;; sort of like a quotient times the deriva-dand.
   (let*
       (($simp t)
-       (dsym '((wxxmltag simp) "d" "s"))
        (arg (cadr x)) ;; the function being differentiated
        (difflist (cddr x)) ;; list of derivs e.g. (x 1 y 2)
        (ords (odds difflist 0)) ;; e.g. (1 2)
        (ords (cond ((null ords) '(1))
                    (t ords)))
        (vars (odds difflist 1)) ;; e.g. (x y)
+       (dsym '((wxxmltag simp) "d" "s"))
        (numer `((mexpt) ,dsym ((mplus) ,@ords))) ; d^n numerator
        (denom (cons '(mtimes)
                     (mapcan #'(lambda(b e)
@@ -944,13 +952,16 @@
 (defprop mtext wxxml-matchfix-np wxxml)
 (defprop mtext (("")"") wxxmlsym)
 
+(defvar *wxxml-mratp* nil)
+
 (defun wxxml-mlable (x l r)
   (wxxml (caddr x)
          (append l
                  (if (cadr x)
                      (list
-		      (format nil "<lbl>(~A) </lbl>"
-			      (stripdollar (maybe-invert-string-case (symbol-name (cadr x))))))
+		      (format nil "<lbl>(~A)~A </lbl>"
+			      (stripdollar (maybe-invert-string-case (symbol-name (cadr x))))
+				  *wxxml-mratp*))
 		     nil))
          r 'mparen 'mparen))
 
@@ -962,8 +973,10 @@
 (defprop spaceout wxxml-spaceout wxxml)
 
 (defun mydispla (x)
-  (mapc #'princ
-	(wxxml x '("<mth>") '("</mth>") 'mparen 'mparen)))
+  (let ((*print-circle* nil)
+	    (*wxxml-mratp* (format nil "~{~a~}" (cdr (checkrat x)))))
+	(mapc #'princ
+		(wxxml x '("<mth>") '("</mth>") 'mparen 'mparen))))
 
 (setf *alt-display2d* 'mydispla)
 
@@ -1237,7 +1250,8 @@
   "")
 
 
-(setf (get '$draw 'autoload) "draw")
+(dolist (fun '($draw $draw2d $draw3d $set_draw_defaults))
+  (setf (get fun 'autoload) "draw"))
 
 (defun $wxdraw2d (&rest args)
   (apply #'$wxdraw
@@ -1293,6 +1307,7 @@
 
 (defun $wxcontour_plot (&rest args)
   (let ((preamble ($wxplot_preamble))
+	($plot_options $plot_options)
 	(system-preamble (get-plot-option-string '$gnuplot_preamble 2))
 	(filename (wxplot-filename)))
     (when (string= system-preamble "false")
@@ -1301,9 +1316,9 @@
     (dolist (arg args)
       (if (and (listp arg) (eql (cadr arg) '$gnuplot_preamble))
 	  (setq preamble (format nil "~a; ~a" preamble (caddr arg)))))
+    ($set_plot_option `((mlist simp) $gnuplot_preamble ,preamble))
     (apply #'$contour_plot `(,@args
 			     ((mlist simp) $plot_format $gnuplot)
-			     ((mlist simp) $gnuplot_preamble ,preamble)
 			     ((mlist simp) $gnuplot_term $png)
 			     ((mlist simp) $gnuplot_out_file ,filename)))
 
@@ -1414,6 +1429,7 @@
 
 (defun $print_function (fun)
   (let ((fun-name (symbol-to-string (caar fun)))
+	(*print-circle* nil)
 	(args (mapcar (lambda (u)
 			(cond ((atom u) (symbol-to-string u))
 			      ((eq (caar u) 'mlist)
@@ -1423,8 +1439,9 @@
     (format nil "FUNCTION: ~a$TEMPLATE: ~a(~{<~a>~^, ~})" fun-name fun-name args)))
 
 (defun $add_function_template (&rest functs)
-  (format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>" (mapcar #'$print_function functs))
-  (cons '(mlist simp) functs))
+  (let ((*print-circle* nil))
+    (format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>" (mapcar #'$print_function functs))
+    (cons '(mlist simp) functs)))
 
 ;;;
 ;;; Rewrite of the function load (maxima/src/mload.lisp)
@@ -1441,7 +1458,8 @@
        (($maxima)
 	($batchload searched-for)
 	(format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>"
-		(mapcar #'$print_function (cdr ($append $functions $macros)))))
+		(append (mapcar #'$print_function (cdr ($append $functions $macros)))
+			(mapcar #'symbol-to-string (cdr $values)))))
        (($lisp $object)
 	;; do something about handling errors
 	;; during loading. Foobar fail act errors.
@@ -1450,9 +1468,56 @@
 	(merror "Maxima bug: Unknown file type ~M" type)))
      searched-for)))
 
+;;;;;;;;;;;;;;;;;;;;;
+;; table_form implementation
+
+(defun make-zeros (n)
+  (cons '(mlist simp) (loop for i from 1 to n collect "")))
+(defun take-first (l n)
+  (if (= n 0) nil (cons (first l) (take-first (rest l) (- n 1)))))
+
+(defun $table_form (mat &rest opts)
+  (when (mapatom mat)
+    ($error "table_form: the argument should not be an atom."))
+  (setq mat ($args mat))
+  (unless (every #'$listp (cdr mat))
+    ($error "table_form: data can not be displayed as a table."))
+  (setq opts (cons '(mlist simp) opts))
+  (let ((row-names ($assoc '$row_names opts))
+	(col-names ($assoc '$column_names opts))
+	(m (apply #'max (mapcar '$length (cdr mat))))
+	(n (length (cdr mat)))
+	(mtrx '(special)))
+    (when (eq row-names '$auto)
+      (setq row-names (cons '(mlist simp) (loop for i from 1 to n collect i))))
+    (when (eq col-names '$auto)
+      (setq col-names (cons '(mlist simp) (loop for i from 1 to m collect i))))
+    (when row-names
+      (setq row-names ($append row-names (make-zeros (- n ($length row-names)))))
+      (setq row-names (cons '(mlist simp) (take-first (cdr row-names) n))))
+    (when col-names
+      (setq col-names ($append col-names (make-zeros (- m ($length col-names)))))
+      (setq col-names (cons '(mlist simp) (take-first (cdr col-names) m))))
+    (when (and row-names col-names)
+      (setq col-names ($cons "" col-names)))
+    (setq mat (cons '(mlist simp) (mapcar
+				   (lambda (r) ($append r (make-zeros (- m ($length r)))))
+				   (cdr mat))))
+    (setq mat ($apply '$matrix mat))
+    (when row-names
+      (setq mat (cons '($matrix simp)
+		      (mapcar #'$append (cdr ($transpose row-names)) (cdr mat))))
+      (setq mtrx (cons 'rownames mtrx)))
+    (when col-names
+      (setq mat (cons '(matrix simp)
+		      (cons col-names (cdr mat))))
+      (setq mtrx (cons 'colnames mtrx)))
+    (cons (append '($matrix simp) mtrx) (cdr mat))))
+
 ;; Load the initial functions (from mac-init.mac)
-(format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>"
-	(mapcar #'$print_function (cdr ($append $functions $macros))))
+(let ((*print-circle* nil))
+  (format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>"
+	  (mapcar #'$print_function (cdr ($append $functions $macros)))))
 
 (when ($file_search "wxmaxima-init")
   ($load "wxmaxima-init"))
