@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -26,29 +26,62 @@
 CellParser::CellParser(wxDC& dc) : m_dc(dc)
 {
   m_scale = 1.0;
+  m_zoomFactor = 1.0; // affects returned fontsizes
   m_top = -1;
   m_bottom = -1;
   m_forceUpdate = false;
   m_indent = MC_GROUP_LEFT_INDENT;
   m_changeAsterisk = false;
   m_outdated = false;
+  m_TeXFonts = false;
+
+  if (wxFontEnumerator::IsValidFacename(m_fontCMEX = wxT("jsMath-cmex10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMSY = wxT("jsMath-cmsy10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMRI = wxT("jsMath-cmr10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMMI = wxT("jsMath-cmmi10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMTI = wxT("jsMath-cmti10")))
+  {
+    m_TeXFonts = true;
+    wxConfig::Get()->Read(wxT("usejsmath"), &m_TeXFonts);
+  }
+
   ReadStyle();
 }
 
 CellParser::CellParser(wxDC& dc, double scale) : m_dc(dc)
 {
   m_scale = scale;
+  m_zoomFactor = 1.0; // affects returned fontsizes
   m_top = -1;
   m_bottom = -1;
-  m_haveGreekFont = false;
-  m_greekFontAdj = 0;
   m_changeAsterisk = false;
+
+  if (wxFontEnumerator::IsValidFacename(m_fontCMEX = wxT("jsMath-cmex10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMSY = wxT("jsMath-cmsy10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMRI = wxT("jsMath-cmr10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMMI = wxT("jsMath-cmmi10")) &&
+      wxFontEnumerator::IsValidFacename(m_fontCMTI = wxT("jsMath-cmti10")))
+  {
+    m_TeXFonts = true;
+    wxConfig::Get()->Read(wxT("usejsmath"), &m_TeXFonts);
+  }
+
   ReadStyle();
 }
 
 CellParser::~CellParser()
 {}
 
+wxString CellParser::GetFontName(int type)
+{
+  if (type == TS_TITLE || type == TS_SUBSECTION || type == TS_SECTION || type == TS_TEXT)
+    return m_styles[type].font;
+  else if (type == TS_NUMBER || type == TS_VARIABLE || type == TS_FUNCTION ||
+      type == TS_SPECIAL_CONSTANT || type == TS_STRING)
+    return m_mathFontName;
+  return m_fontName;
+}
+
 void CellParser::ReadStyle()
 {
   wxConfigBase* config = wxConfig::Get();
@@ -56,24 +89,21 @@ void CellParser::ReadStyle()
   // Font
   config->Read(wxT("Style/fontname"), &m_fontName);
 
+  // Default fontsize
+  m_defaultFontSize = 12;
+  config->Read(wxT("fontSize"), &m_defaultFontSize);
+  m_mathFontSize = m_defaultFontSize;
+  config->Read(wxT("mathfontsize"), &m_mathFontSize);
+
   // Encogind - used only for comments
   m_fontEncoding = wxFONTENCODING_DEFAULT;
   int encoding = m_fontEncoding;
   config->Read(wxT("fontEncoding"), &encoding);
   m_fontEncoding = (wxFontEncoding)encoding;
 
-  // Greek font
-  m_haveGreekFont = false;
-  m_greekFontAdj = 0;
-  m_greekFontName = wxEmptyString;
-  config->Read(wxT("Style/GreekFont/fontname"), &m_greekFontName);
-  config->Read(wxT("Style/GreekFont/adj"), &m_greekFontAdj);
-  config->Read(wxT("Style/GreekFont/ok"), &m_haveGreekFont);
-
-#if (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
-  m_unicodeSymbolsFont = wxT("Sans");
-  config->Read(wxT("Style/Unicode/fontname"), &m_unicodeSymbolsFont);
-#endif
+  // Math font
+  m_mathFontName = wxEmptyString;
+  config->Read(wxT("Style/Math/fontname"), &m_mathFontName);
 
   wxString tmp;
 
@@ -102,6 +132,18 @@ void CellParser::ReadStyle()
                &m_styles[TS_TEXT].font);
   READ_STYLES(TS_TEXT, "Style/Text/")
 
+  // Subsection
+  m_styles[TS_SUBSECTION].color = wxT("black");
+  m_styles[TS_SUBSECTION].bold = true;
+  m_styles[TS_SUBSECTION].italic = false;
+  m_styles[TS_SUBSECTION].underlined = false;
+  m_styles[TS_SUBSECTION].fontSize = 16;
+  config->Read(wxT("Style/Subsection/fontsize"),
+               &m_styles[TS_SUBSECTION].fontSize);
+  config->Read(wxT("Style/Subsection/fontname"),
+               &m_styles[TS_SUBSECTION].font);
+  READ_STYLES(TS_SUBSECTION, "Style/Subsection/")
+
   // Section
   m_styles[TS_SECTION].color = wxT("black");
   m_styles[TS_SECTION].bold = true;
@@ -202,7 +244,7 @@ void CellParser::ReadStyle()
                    &tmp)) m_styles[TS_HIGHLIGHT].color.Set(tmp);
 
   // Text background
-  m_styles[TS_TEXT_BACKGROUND].color = wxColour(wxT("white"));
+  m_styles[TS_TEXT_BACKGROUND].color = wxColour(wxT("light blue"));
   if (config->Read(wxT("Style/TextBackground/color"),
                    &tmp)) m_styles[TS_TEXT_BACKGROUND].color.Set(tmp);
 
@@ -220,8 +262,12 @@ void CellParser::ReadStyle()
   if (config->Read(wxT("Style/Cursor/color"),
                    &tmp)) m_styles[TS_CURSOR].color.Set(tmp);
 
-  // Selection color
-  m_styles[TS_SELECTION].color = wxT("light grey"); // on mac should default to system selection color
+  // Selection color defaults to light grey on windows
+#if defined __WXMSW__
+  m_styles[TS_SELECTION].color = wxColour(wxT("light grey"));
+#else
+  m_styles[TS_SELECTION].color = wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHT);
+#endif
   if (config->Read(wxT("Style/Selection/color"),
                    &tmp)) m_styles[TS_SELECTION].color.Set(tmp);
 
@@ -246,8 +292,8 @@ wxFontWeight CellParser::IsBold(int st)
 int CellParser::IsItalic(int st)
 {
   if (m_styles[st].italic)
-    return wxSLANT;
-  return wxNORMAL;
+    return wxFONTSTYLE_SLANT;
+  return wxFONTSTYLE_NORMAL;
 }
 
 int CellParser::IsUnderlined(int st)
@@ -261,11 +307,8 @@ wxString CellParser::GetSymbolFontName()
 {
 #if defined __WXMSW__
   return wxT("Symbol");
-#elif (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
-  return m_unicodeSymbolsFont;
-#else
-  return m_fontName;
 #endif
+  return m_fontName;
 }
 
 wxColour CellParser::GetColor(int st)
@@ -275,6 +318,7 @@ wxColour CellParser::GetColor(int st)
   return m_styles[st].color;
 }
 
+/*
 wxFontEncoding CellParser::GetGreekFontEncoding()
 {
 #if wxUSE_UNICODE || defined (__WXGTK20__) || defined (__WXMAC__)
@@ -285,3 +329,4 @@ wxFontEncoding CellParser::GetGreekFontEncoding()
   return wxFONTENCODING_ISO8859_7;
 #endif
 }
+*/
