@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #define _CELLPARSER_H
 
 #include <wx/wx.h>
+#include <wx/fontenum.h>
+
 #include "TextStyle.h"
 
 #include "Setup.h"
@@ -31,20 +33,11 @@ public:
   CellParser(wxDC& dc);
   CellParser(wxDC& dc, double scale);
   ~CellParser();
-  void SetScale(double scale)
-  {
-    m_scale = scale;
-  }
-  double GetScale()
-  {
-    return m_scale;
-  }
-  wxDC& GetDC()
-  {
-    return m_dc;
-  }
-  void SetBouns(int top, int bottom)
-  {
+  void SetZoomFactor(double newzoom) { m_zoomFactor = newzoom; }
+  void SetScale(double scale) { m_scale = scale; }
+  double GetScale() { return m_scale; }
+  wxDC& GetDC() { return m_dc; }
+  void SetBounds(int top, int bottom) {
     m_top = top;
     m_bottom = bottom;
   }
@@ -56,26 +49,8 @@ public:
   {
     return m_bottom;
   }
-  wxString GetFontName(int type = TS_DEFAULT)
-  {
-    if (type == TS_TITLE || type == TS_SECTION || type == TS_TEXT)
-      return m_styles[type].font;
-    return m_fontName;
-  }
+  wxString GetFontName(int type = TS_DEFAULT);
   wxString GetSymbolFontName();
-  wxString GetGreekFontName()
-  {
-    return m_greekFontName;
-  }
-  wxFontEncoding GetGreekFontEncoding();
-  int GetGreekFontAdj()
-  {
-    return m_greekFontAdj;
-  }
-  bool HaveGreekFont()
-  {
-    return m_haveGreekFont;
-  }
   wxColour GetColor(int st);
   wxFontWeight IsBold(int st);
   int IsItalic(int st);
@@ -105,28 +80,35 @@ public:
   void SetIndent(int indent) { m_indent = indent; }
   void SetClientWidth(int width) { m_clientWidth = width; }
   int GetClientWidth() { return m_clientWidth; }
+  int GetDefaultFontSize() { return int(m_zoomFactor * double(m_defaultFontSize)); }
+  int GetMathFontSize() { return int(m_zoomFactor * double(m_mathFontSize)); }
   int GetFontSize(int st)
   {
-    if (st == TS_TEXT || st == TS_SECTION || st == TS_TITLE)
-      return m_styles[st].fontSize;
+    if (st == TS_TEXT || st == TS_SUBSECTION || st == TS_SECTION || st == TS_TITLE)
+      return int(m_zoomFactor * double(m_styles[st].fontSize));
     return 0;
   }
   void Outdated(bool outdated) { m_outdated = outdated; }
+  bool CheckTeXFonts() { return m_TeXFonts; }
+  wxString GetTeXCMRI() { return m_fontCMRI; }
+  wxString GetTeXCMSY() { return m_fontCMSY; }
+  wxString GetTeXCMEX() { return m_fontCMEX; }
+  wxString GetTeXCMMI() { return m_fontCMMI; }
+  wxString GetTeXCMTI() { return m_fontCMTI; }
 private:
   int m_indent;
   double m_scale;
+  double m_zoomFactor;
   wxDC& m_dc;
   int m_top, m_bottom;
   wxString m_fontName;
-  wxString m_greekFontName;
-#if (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
-  wxString m_unicodeSymbolsFont;
-#endif
-  int m_greekFontAdj;
-  bool m_haveGreekFont;
+  int m_defaultFontSize, m_mathFontSize;
+  wxString m_mathFontName;
   bool m_forceUpdate;
   bool m_changeAsterisk;
   bool m_outdated;
+  bool m_TeXFonts;
+  wxString m_fontCMRI, m_fontCMSY, m_fontCMEX, m_fontCMMI, m_fontCMTI;
   int m_clientWidth;
   wxFontEncoding m_fontEncoding;
   style m_styles[STYLE_NUM];
