@@ -43,8 +43,10 @@ const int langs[] =
     wxLANGUAGE_ENGLISH,
     wxLANGUAGE_FRENCH,
     wxLANGUAGE_GERMAN,
+    wxLANGUAGE_GREEK,
     wxLANGUAGE_HUNGARIAN,
     wxLANGUAGE_ITALIAN,
+    wxLANGUAGE_JAPANESE,
     wxLANGUAGE_POLISH,
     wxLANGUAGE_PORTUGUESE_BRAZILIAN,
     wxLANGUAGE_RUSSIAN,
@@ -52,7 +54,7 @@ const int langs[] =
     wxLANGUAGE_UKRAINIAN
   };
 
-#define LANGUAGE_NUMBER 14
+#define LANGUAGE_NUMBER 16
 
 Config::Config(wxWindow* parent, int id, const wxString& title,
                const wxPoint& pos, const wxSize& size, long style):
@@ -83,8 +85,10 @@ Config::Config(wxWindow* parent, int id, const wxString& title,
       _("English"),
       _("French"),
       _("German"),
+      _("Greek"),
       _("Hungarian"),
       _("Italian"),
+      _("Japanese"),
       _("Polish"),
       _("Portuguese (Brazilian)"),
       _("Russian"),
