@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -35,14 +35,10 @@ enum {
   checkbox_bold,
   checkbox_italic,
   checkbox_underlined,
-  checkbox_header,
-  button_greek,
-  checkbox_greek,
+  button_mathFont,
   font_family,
   style_font_family,
-  panel_size,
   language_id,
-  unicode_glyphs,
   save_id,
   load_id
 };
@@ -106,12 +102,10 @@ protected:
   wxTextCtrl* m_additionalParameters;
   wxStaticText* label_4;
   wxComboBox* m_language;
-  wxStaticText* label_9;
-  wxComboBox* m_panelSize;
   wxCheckBox* m_saveSize;
+  wxCheckBox* m_savePanes;
   wxCheckBox* m_matchParens;
   wxCheckBox* m_showLong;
-  wxCheckBox* m_showHeader;
   wxCheckBox* m_enterEvaluates;
   wxPanel* notebook_1_pane_1;
   wxStaticText* label_8;
@@ -130,21 +124,16 @@ protected:
   wxCheckBox* m_fixedFontInTC;
   wxCheckBox* m_unixCopy;
   wxCheckBox* m_changeAsterisk;
+  wxCheckBox* m_useJSMath;
   wxPanel* notebook_1_pane_2;
   wxNotebook* notebook_1;
   wxButton* m_button1;
   wxButton* m_button2;
-  wxCheckBox* m_greekFontOk;
-  wxButton* m_getGreekFont;
+  wxStaticText* m_mathFont;
+  wxButton* m_getMathFont;
   wxStaticText* label_10;
-  wxSpinCtrl* m_greekFontAdj;
-  wxString m_greekFontName;
+  wxString m_mathFontName;
   wxButton *m_saveStyle, *m_loadStyle;
-#if (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
-  wxStaticText* m_unicodeGlyphs;
-  wxButton* m_getUnicodeFont;
-  wxString m_unicodeFont;
-#endif
   wxStaticText* label_12;
   wxSpinCtrl* m_defaultPort;
   ExamplePanel* label_11;
@@ -162,6 +151,7 @@ protected:
         m_styleLabel,
         m_styleHighlight,
         m_styleText,
+        m_styleSubsection,
         m_styleSection,
         m_styleTitle,
         m_styleTextBackground,
@@ -173,27 +163,24 @@ protected:
         m_styleOutdated;
   void OnOk(wxCommandEvent& event);
   void OnMpBrowse(wxCommandEvent& event);
-#if (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
-  void OnChangeUnicodeFont(wxCommandEvent& event);
-#endif
 #if defined __WXMSW__
   void OnColorButton(wxCommandEvent& event);
 #endif
-  void OnGreekBrowse(wxCommandEvent& event);
+  void OnMathBrowse(wxCommandEvent& event);
   void OnChangeStyle(wxCommandEvent& event);
   void OnChangeWarning(wxCommandEvent& event);
   void OnCheckbox(wxCommandEvent& event);
-  void OnCheckGreek(wxCommandEvent& event);
   void ReadStyles(wxString file = wxEmptyString);
   void WriteStyles(wxString file = wxEmptyString);
   void SetupFontList();
   void UpdateExample();
   void OnChangeFontFamily(wxCommandEvent& event);
   void LoadSave(wxCommandEvent& event);
-  int m_fontSize;
+  int m_fontSize, m_mathFontSize;
   style* GetStylePointer();
   DECLARE_EVENT_TABLE()
 };
+
 #ifndef __WXMSW__
 class ColorPanel : public wxPanel
 {
