@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2006-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2006-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -37,11 +37,7 @@ public:
   wxString ToXML(bool all);
   void SetFont(CellParser& parser, int fontsize);
   void SetForeground(CellParser& parser);
-  void SetValue(wxString text)
-  {
-    m_text = text;
-    m_positionOfCaret = m_text.Length();
-  }
+  void SetValue(wxString text);
   wxString GetValue()
   {
     return m_text;
@@ -55,11 +51,11 @@ public:
   wxPoint PositionToPoint(CellParser& parser, int pos = -1);
   void SelectPointText(wxDC &dc, wxPoint& point);
   void SelectRectText(wxDC &dc, wxPoint& one, wxPoint& two);
-  wxString SelectWordUnderCaret();
+  wxString SelectWordUnderCaret(bool selectParens = true, bool toRight = true);
   bool IsPointInSelection(wxDC& dc, wxPoint point);
   bool CopyToClipboard();
   bool CutToClipboard();
-  void PasteFromClipboard();
+  void PasteFromClipboard(bool primary = false);
   void SelectAll()
   {
     m_selectionStart = 0;
@@ -87,20 +83,43 @@ public:
   {
     m_hasFocus = focus;
   }
+  void SetFirstLineOnly(bool show = true) {
+    if (m_firstLineOnly != show) { m_width = m_height = -1; m_firstLineOnly = show; }}
   bool IsActive() { return m_isActive; }
   bool CaretAtStart() { return m_positionOfCaret == 0; }
-  void CaretToStart() { m_positionOfCaret = 0; }
-  bool CaretAtEnd() { return m_positionOfCaret == m_text.Length(); }
-  void CaretToEnd() { m_positionOfCaret = m_text.Length(); }
-  void CaretToPosition(int pos) { m_positionOfCaret = pos; }
+  void CaretToStart();
+  bool CaretAtEnd() { return m_positionOfCaret == (signed)m_text.Length(); }
+  void CaretToEnd();
+  void CaretToPosition(int pos);
   bool CanUndo() { return m_text != m_oldText; }
   void SaveValue();
   void Undo();
+  wxString DivideAtCaret();
+  void CommentSelection();
   void ClearUndo() { m_oldText = wxEmptyString; m_oldPosition = 0; }
   bool ContainsChanges() { return m_containsChanges; }
   void ContainsChanges(bool changes) { m_containsChanges = m_containsChangesCheck = changes; }
   bool CheckChanges();
+  int ReplaceAll(wxString oldString, wxString newString);
+  bool FindNext(wxString str, bool down, bool ignoreCase);
+  void SetSelection(int start, int end)
+  {
+    m_selectionStart = start;
+    m_positionOfCaret = m_selectionEnd = end;
+  }
+  void GetSelection(int *start, int *end)
+  {
+    *start = m_selectionStart; *end = m_selectionEnd;
+  }
+  bool ReplaceSelection(wxString oldStr, wxString newString);
+  wxString GetSelectionString();
+  void ClearSelection();
+  int GetCaretPosition() { return m_positionOfCaret; }
+  bool FindNextTemplate(bool left = false);
 private:
+#if wxUSE_UNICODE
+  wxString InterpretEscapeString(wxString txt);
+#endif
   wxString m_text;
   wxString m_oldText;
   int m_oldPosition;
@@ -127,6 +146,7 @@ private:
   bool m_saveValue;
   bool m_containsChanges;
   bool m_containsChangesCheck;
+  bool m_firstLineOnly;
 };
 
 #endif
