@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 #include "FracCell.h"
 #include "TextCell.h"
 
+#define FRAC_DEC 1
+
 FracCell::FracCell() : MathCell()
 {
   m_num = NULL;
@@ -114,22 +116,26 @@ void FracCell::SetDenom(MathCell *denom)
 void FracCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
 {
   double scale = parser.GetScale();
-  if (m_isBroken)
+  if (m_isBroken || m_exponent)
   {
     m_num->RecalculateWidths(parser, fontsize, true);
     m_denom->RecalculateWidths(parser, fontsize, true);
   }
   else
   {
-    m_num->RecalculateWidths(parser, MAX(MC_MIN_SIZE, fontsize - 2), true);
-    m_denom->RecalculateWidths(parser, MAX(MC_MIN_SIZE, fontsize - 2), true);
+    m_num->RecalculateWidths(parser, MAX(MC_MIN_SIZE, fontsize - FRAC_DEC), true);
+    m_denom->RecalculateWidths(parser, MAX(MC_MIN_SIZE, fontsize - FRAC_DEC), true);
   }
   if (m_exponent && !m_isBroken)
   {
     wxDC& dc = parser.GetDC();
-    int width, height;
-    dc.GetTextExtent(wxT("/"), &width, &height);
-    m_width = m_num->GetFullWidth(scale) + m_denom->GetFullWidth(scale) + width;
+    int height;
+    int fontsize1 = (int) ((double)(fontsize) * scale + 0.5);
+    dc.SetFont(wxFont(fontsize1, wxMODERN,
+                            false, false, false,
+                            parser.GetFontName(TS_VARIABLE)));
+    dc.GetTextExtent(wxT("/"), &m_expDivideWidth, &height);
+    m_width = m_num->GetFullWidth(scale) + m_denom->GetFullWidth(scale) + m_expDivideWidth;
   }
   else
   {
@@ -146,15 +152,15 @@ void FracCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
 void FracCell::RecalculateSize(CellParser& parser, int fontsize, bool all)
 {
   double scale = parser.GetScale();
-  if (m_isBroken)
+  if (m_isBroken || m_exponent)
   {
     m_num->RecalculateSize(parser, fontsize, true);
     m_denom->RecalculateSize(parser, fontsize, true);
   }
   else
   {
-    m_num->RecalculateSize(parser, MAX(MC_MIN_SIZE, fontsize - 2), true);
-    m_denom->RecalculateSize(parser, MAX(MC_MIN_SIZE, fontsize - 2), true);
+    m_num->RecalculateSize(parser, MAX(MC_MIN_SIZE, fontsize - FRAC_DEC), true);
+    m_denom->RecalculateSize(parser, MAX(MC_MIN_SIZE, fontsize - FRAC_DEC), true);
   }
   if (!m_exponent)
   {
@@ -186,31 +192,34 @@ void FracCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
 
     if (m_exponent && !m_isBroken)
     {
-      int width, height;
       double scale = parser.GetScale();
-      dc.GetTextExtent(wxT("/"), &width, &height);
+
       num.x = point.x;
       num.y = point.y;
-      denom.x = point.x + m_num->GetFullWidth(scale) + width;
+      denom.x = point.x + m_num->GetFullWidth(scale) + m_expDivideWidth;
       denom.y = num.y;
 
-      dc.GetTextExtent(wxT("/"), &width, &height);
-      m_num->Draw(parser, num, MAX(MC_MIN_SIZE, fontsize - 2), true);
-      m_denom->Draw(parser, denom, MAX(MC_MIN_SIZE, fontsize - 2), true);
+      m_num->Draw(parser, num, fontsize, true);
+      m_denom->Draw(parser, denom, fontsize, true);
+
+      int fontsize1 = (int) ((double)(fontsize) * scale + 0.5);
+      dc.SetFont(wxFont(fontsize1, wxMODERN,
+                              false, false, false,
+                              parser.GetFontName(TS_VARIABLE)));
       dc.DrawText(wxT("/"),
                   point.x + m_num->GetFullWidth(scale),
-                  point.y - m_num->GetMaxCenter() + SCALE_PX(2, scale));
+                  point.y - m_num->GetMaxCenter() + SCALE_PX(MC_TEXT_PADDING, scale));
     }
     else
     {
       num.x = point.x + (m_width - m_num->GetFullWidth(scale)) / 2;
       num.y = point.y - m_num->GetMaxHeight() + m_num->GetMaxCenter() -
               SCALE_PX(2, scale);
-      m_num->Draw(parser, num, MAX(MC_MIN_SIZE, fontsize - 2), true);
+      m_num->Draw(parser, num, MAX(MC_MIN_SIZE, fontsize - FRAC_DEC), true);
 
       denom.x = point.x + (m_width - m_denom->GetFullWidth(scale)) / 2;
       denom.y = point.y + m_denom->GetMaxCenter() + SCALE_PX(2, scale);
-      m_denom->Draw(parser, denom, MAX(MC_MIN_SIZE, fontsize - 2), true);
+      m_denom->Draw(parser, denom, MAX(MC_MIN_SIZE, fontsize - FRAC_DEC), true);
       SetPen(parser);
       if (m_fracStyle != FC_CHOOSE)
         dc.DrawLine(point.x, point.y, point.x + m_width, point.y);
@@ -273,8 +282,8 @@ wxString FracCell::ToTeX(bool all)
   {
     if (m_fracStyle == FC_CHOOSE)
     {
-      s = wxT("\\pmatrix{") + m_num->ToTeX(true) + wxT("\\cr ") +
-          m_denom->ToTeX(true) + wxT("}");
+      s = wxT("\\begin{pmatrix}") + m_num->ToTeX(true) + wxT("\\cr ") +
+          m_denom->ToTeX(true) + wxT("\\end{pmatrix}");
     }
     else
     {
@@ -291,11 +300,11 @@ wxString FracCell::ToXML(bool all)
 {
 	if( m_isBroken )
 		return wxEmptyString;
-	wxString s = ( m_fracStyle == FC_NORMAL || m_fracStyle == FC_DIFF )? 
+	wxString s = ( m_fracStyle == FC_NORMAL || m_fracStyle == FC_DIFF )?
 					_T("f"): _T("f line = \"no\"");
-	return _T("<") + s + _T("><r>") + 
+	return _T("<") + s + _T("><r>") +
 			m_num->ToXML(true) + _T("</r><r>") +
-			m_denom->ToXML(true) + _T("</r></f>") + 
+			m_denom->ToXML(true) + _T("</r></f>") +
 			MathCell::ToXML(all);
 }
 
