@@ -538,7 +538,7 @@ void GroupCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
       points[3].x = point.x;
       points[3].y = point.y - m_center;
       dc.DrawPolygon(4, points);
-      delete(points);
+      delete [] points;
     }
     else { // draw a triangle and line
       wxPoint *points = new wxPoint[3];
@@ -549,7 +549,7 @@ void GroupCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
       points[2].x = point.x;
       points[2].y = point.y - m_center;
       dc.DrawPolygon(3, points);
-      delete(points);
+      delete [] points;
 
       // vertical
       dc.DrawLine(point.x - SCALE_PX(10, scale), point.y - m_center,
@@ -594,6 +594,20 @@ wxString GroupCell::ToString(bool all)
   return str + MathCell::ToString(all);
 }
 
+wxString GroupCell::PrepareForTeX(wxString str)
+{
+  str.Replace(wxT("\\"), wxT("\\verb|\\|"));
+  str.Replace(wxT("_"), wxT("\\_"));
+  str.Replace(wxT("%"), wxT("\\%"));
+  str.Replace(wxT("{"), wxT("\\{"));
+  str.Replace(wxT("}"), wxT("\\}"));
+  str.Replace(wxT("^"), wxT("\\verb|^|"));
+  str.Replace(wxT(">"), wxT("\\verb|>|"));
+  str.Replace(wxT("<"), wxT("\\verb|<|"));
+
+  return str;
+}
+
 wxString GroupCell::ToTeX(bool all)
 {
   return ToTeX(all, wxEmptyString, wxEmptyString, NULL);
@@ -627,7 +641,7 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
           << wxT("  \\begin{center}\n")
           << wxT("    \\includegraphics{")
           << filename << wxT("_img/") << image << wxT("}\n")
-          << wxT("  \\caption{") << m_input->m_next->GetValue() << wxT("}\n")
+          << wxT("  \\caption{") << PrepareForTeX(m_input->m_next->GetValue()) << wxT("}\n")
           << wxT("  \\end{center}\n")
           << wxT("\\end{figure}");
     }
@@ -637,11 +651,29 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
 
   // CODE CELLS
   else if (m_groupType == GC_TYPE_CODE) {
-    str = wxT("\n\\begin{verbatim}\n") + m_input->ToString(true) + wxT("\n\\end{verbatim}\n");
+    // Input cells
+    str = wxT("\n\\noindent\n%%%%%%%%%%%%%%%\n")
+          wxT("%%% INPUT:\n")
+          wxT("\\begin{minipage}[t]{1.5cm}{\\color{red}\\bf\n")
+          wxT("\\begin{verbatim}\n") +
+          m_input->ToString(false) +
+          wxT("\n\\end{verbatim}}\n\\end{minipage}");
+
+    if (m_input->m_next!=NULL)
+    {
+      str += wxT("\n\\begin{minipage}[t]{\\textwidth}{\\color{blue}\n\\begin{verbatim}\n") +
+             m_input->m_next->ToString(true) +
+             wxT("\n\\end{verbatim}}\n\\end{minipage}");
+    }
+
+    str += wxT("\n");
 
     if (m_output != NULL) {
-      str += wxT("$$\n");
-      wxString label;
+      str += wxT("%%% OUTPUT:\n");
+      // Need to define labelcolor if this is Copy as LaTeX!
+      if (imgCounter == NULL)
+        str += wxT("\\definecolor{labelcolor}{RGB}{100,0,0}\n");
+      str += wxT("\\begin{math}\\displaystyle\n");
       MathCell *tmp = m_output;
 
       while (tmp != NULL) {
@@ -672,9 +704,9 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
 
         else if (tmp->GetStyle() == TS_LABEL)
         {
-          if (str.Right(3) != wxT("$$\n"))
-            str += label + wxT("\n$$\n$$\n");
-          label = wxT("\\leqno{\\tt ") + tmp->ToTeX(false) + wxT(" }");
+          if (str.Right(13) != wxT("displaystyle\n"))
+            str += wxT("\n\\end{math}\n\n\\begin{math}\\displaystyle\n");
+          str += wxT("\\mathrm{\\color{labelcolor}") + tmp->ToTeX(false) + wxT("}\\quad");
         }
 
         else
@@ -682,7 +714,7 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
 
         tmp = tmp->m_nextToDraw;
       }
-      str += label + wxT("\n$$\n");
+      str += wxT("\n\\end{math}\n%%%%%%%%%%%%%%%\n");
     }
   }
 
@@ -691,21 +723,22 @@ wxString GroupCell::ToTeX(bool all, wxString imgDir, wxString filename, int *img
     str = GetEditable()->ToTeX(true);
     switch (GetEditable()->GetStyle()) {
       case TS_TITLE:
-        str = wxT("\n\\pagebreak{}\n{\\Huge {\\sc ") + str + wxT("}}\n");
+        str = wxT("\n\\pagebreak{}\n{\\Huge {\\sc ") + PrepareForTeX(str) + wxT("}}\n");
         str += wxT("\\setcounter{section}{0}\n\\setcounter{subsection}{0}\n");
-        str += wxT("\\setcounter{figure}{0}\n");
+        str += wxT("\\setcounter{figure}{0}\n\n");
         break;
       case TS_SECTION:
-        str = wxT("\n\\section{") + str + wxT("}\n");
+        str = wxT("\n\\section{") + PrepareForTeX(str) + wxT("}\n\n");
         break;
       case TS_SUBSECTION:
-        str = wxT("\n\\subsection{") + str + wxT("}\n");
+        str = wxT("\n\\subsection{") + PrepareForTeX(str) + wxT("}\n\n");
         break;
       default:
-        if (!str.StartsWith(wxT("TeX:")))
-          str = wxT("\n\\begin{verbatim}\n") + str + wxT("\n\\end{verbatim}\n");
-        else
-          str = wxT("\n") + str.SubString(5, str.Length()-1) + wxT("\n");
+        if (str.StartsWith(wxT("TeX:")))
+          str = str.Mid(5, str.Length());
+        else {
+          str = PrepareForTeX(str);
+        }
         break;
     }
   }
@@ -1235,3 +1268,11 @@ void GroupCell::Number(int &section, int &subsection, int &image) {
   if (m_next)
     ((GroupCell *)m_next)->Number(section, subsection, image);
 }
+
+bool GroupCell::IsMainInput(MathCell *active)
+{
+  if (m_input->m_next == NULL)
+    return false;
+
+  return (active == m_input->m_next);
+}
