@@ -60,6 +60,7 @@ public:
   // exporting
   wxString ToTeX(bool all, wxString imgDir, wxString filename, int *imgCounter);
   wxString ToTeX(bool all);
+  wxString PrepareForTeX(wxString text);
   wxString ToXML(bool all);
   // hide status
   bool IsHidden() { return m_hide; }
@@ -97,6 +98,7 @@ public:
   GroupCell *FoldAll(bool all = false);
   GroupCell *UnfoldAll(bool all = false);
   bool IsLesserGCType(int comparedTo);
+  bool IsMainInput(MathCell *active);
   void Number(int &section, int &subsection, int &image);
   void RecalculateAppended(CellParser& parser);
   void Draw(CellParser& parser, wxPoint point, int fontsize, bool all);
