@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -58,9 +58,9 @@ protected:
   MathCell *m_var;
   int m_signSize;
   int m_signWidth;
-  int m_signMiddle;
   int m_intStyle;
-#if defined __WXMSW__ || (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+  int m_signTop;
+#if defined __WXMSW__
   int m_charHeight, m_charWidth;
 #endif
 };
