@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -129,8 +129,8 @@ wxString LimitWiz::GetValue()
 
 void LimitWiz::OnButton(wxCommandEvent& event)
 {
-  wxString choices[] = {wxT("Pi"), wxT("E"), wxT("Infinity"),
-                        wxT("- Infinity")};
+  wxString choices[] = {wxT("Pi"), wxT("E"), _("Infinity"),
+                        _("- Infinity")};
   wxString choice = wxGetSingleChoice(_("Select a constant"),
                                       _("Constant"), 4, choices, this);
   if (choice.Length())
@@ -139,9 +139,9 @@ void LimitWiz::OnButton(wxCommandEvent& event)
       text_ctrl_3->SetValue(wxT("%pi"));
     else if (choice == wxT("E"))
       text_ctrl_3->SetValue(wxT("%e"));
-    else if (choice == wxT("Infinity"))
+    else if (choice == _("Infinity"))
       text_ctrl_3->SetValue(wxT("inf"));
-    else if (choice == wxT("- Infinity"))
+    else if (choice == _("- Infinity"))
       text_ctrl_3->SetValue(wxT("minf"));
   }
 }
