@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ MathCell::MathCell()
   m_isBroken = false;
   m_highlight = false;
   m_type = MC_TYPE_DEFAULT;
-  m_textStyle = TS_DEFAULT;
+  m_textStyle = TS_VARIABLE;
 }
 
 /***
@@ -74,6 +74,9 @@ void MathCell::SetType(int type)
 		case MC_TYPE_TEXT:
 			m_textStyle = TS_TEXT;
 			break;
+		case MC_TYPE_SUBSECTION:
+			m_textStyle = TS_SUBSECTION;
+			break;
 		case MC_TYPE_SECTION:
 			m_textStyle = TS_SECTION;
 			break;
@@ -525,3 +528,9 @@ void MathCell::SetForeground(CellParser& parser)
   dc.SetTextForeground(color);
 }
 
+bool MathCell::IsMath()
+{
+  return !(m_textStyle == TS_DEFAULT ||
+           m_textStyle == TS_LABEL ||
+           m_textStyle == TS_INPUT);
+}
