@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #define MC_CELL_SKIP 0
 #define MC_BASE_INDENT 12
 #define MC_LINE_SKIP 2
-#define MC_TEXT_PADDING 2
+#define MC_TEXT_PADDING 1
 
 #define MC_GROUP_SKIP 20
 #define MC_GROUP_LEFT_INDENT 15
@@ -55,6 +55,7 @@ enum {
   MC_TYPE_INPUT,
   MC_TYPE_ERROR,
   MC_TYPE_TEXT,
+  MC_TYPE_SUBSECTION,
   MC_TYPE_SECTION,
   MC_TYPE_TITLE,
   MC_TYPE_IMAGE,
@@ -149,7 +150,7 @@ public:
   bool IsComment()
   {
     return m_type == MC_TYPE_TEXT || m_type == MC_TYPE_SECTION ||
-           m_type == MC_TYPE_TITLE;
+           m_type == MC_TYPE_SUBSECTION || m_type == MC_TYPE_TITLE;
   }
   bool IsEditable(bool input = false)
   {
@@ -159,10 +160,10 @@ public:
   }
   virtual void ProcessEvent(wxKeyEvent& event) { }
   virtual bool ActivateCell() { return false; }
-  virtual bool AddEnding() { }
+  virtual bool AddEnding() { return false; }
   virtual void SelectPointText(wxDC &dc, wxPoint& point) { }
   virtual void SelectRectText(wxDC &dc, wxPoint& one, wxPoint& two) { }
-  virtual void PasteFromClipboard() { }
+  virtual void PasteFromClipboard(bool primary = false) { }
   virtual bool CopyToClipboard() { return false; }
   virtual bool CutToClipboard() { return false; }
   virtual void SelectAll() { }
@@ -175,6 +176,8 @@ public:
   void SetForeground(CellParser& parser);
   virtual bool IsActive() { return false; }
   virtual void SetParent(MathCell *parent, bool all);
+  void SetStyle(int style) { m_textStyle = style; }
+  bool IsMath();
 protected:
   int m_height;
   int m_width;
