@@ -57,7 +57,8 @@ enum {
   popid_insert_input,
   popid_copy_tex,
   popid_image,
-  popid_image_animate,
+  popid_animation_save,
+  popid_animation_start,
   popid_evaluate,
   popid_merge_cells,
   // popid_complete_00 should be the last id
@@ -193,6 +194,7 @@ public:
   bool LoadSymbols(wxString file) { m_autocomplete.LoadSymbols(file); }
   bool Autocomplete(bool templates = false);
   void AddSymbol(wxString fun, bool templ = false) { m_autocomplete.AddSymbol(fun, templ); }
+  void SetActiveCellText(wxString text);
 protected:
   MathCell* CopySelection();
   MathCell* CopySelection(MathCell* start, MathCell* end, bool asData = false);
