@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ public:
   void SetData(MathCell* tree);
   void SetupData();
   void BreakPages();
-  void RecalculateSize();
+  void Recalculate();
   bool OnPrintPage(int num);
   bool HasPage(int num);
   void GetPageInfo(int* minPage, int* maxPage, int* pageFrom, int* pageTo);
@@ -52,7 +52,6 @@ public:
   void GetPageMargins(int* horizontal, int* vertical);
   int GetHeaderHeight();
   void PrintHeader(int pageNum, wxDC* dc, double scale);
-  void RecalculateWidths();
   double GetPPIScale();
   void GetScreenScale(double *scaleX, double *scaleY);
 private:
