@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -43,6 +43,9 @@ public:
 protected:
   MathCell *m_innerCell;
   MathCell *m_open, *m_close, *m_last;
+  int m_signWidth, m_signSize, m_signTop;
+  int m_signType;
+  double m_signFontScale;
 };
 
 #endif //_SQRTCELL_H_
