@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2007 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -56,7 +56,8 @@ protected:
   int m_signSize;
   int m_signWidth;
   int m_sumStyle;
-  int m_signCenter;
+  int m_signWCenter;
+  int m_signTop;
 };
 
 #endif //_UNDERCELL_H_
