@@ -64,6 +64,7 @@ MathCell* TextCell::Copy(bool all)
   tmp->m_isHidden = m_isHidden;
   tmp->m_textStyle = m_textStyle;
   tmp->m_highlight = m_highlight;
+  tmp->SetAltText();
   if (all && m_next != NULL)
     tmp->AppendCell(m_next->Copy(all));
   return tmp;
@@ -84,10 +85,14 @@ void TextCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
     double scale = parser.GetScale();
     SetFont(parser, fontsize);
 
-    /// Labels and prompts are fixed widht - adjust font size so that
+    /// Labels and prompts are fixed width - adjust font size so that
     /// they fit in
     if ((m_textStyle == TS_LABEL) || (m_textStyle == TS_MAIN_PROMPT)) {
-      dc.GetTextExtent(wxT("(\%oXXX)"), &m_width, &m_height);
+	  // Check for output annotations (/R/ for CRE and /T/ for Taylor expressions)
+      if (m_text.Right(2) != wxT("/ "))
+        dc.GetTextExtent(wxT("(\%oXXX)"), &m_width, &m_height);
+      else
+        dc.GetTextExtent(wxT("(\%oXXX)/R/"), &m_width, &m_height);
       m_fontSizeLabel = m_fontSize;
       dc.GetTextExtent(m_text, &m_labelWidth, &m_labelHeight);
       while (m_labelWidth >= m_width) {
@@ -238,7 +243,7 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
     dc.SetFont(wxFont(fontsize1, wxFONTFAMILY_MODERN,
                       parser.IsItalic(m_textStyle),
                       parser.IsBold(m_textStyle),
-                      false,
+                      parser.IsUnderlined(m_textStyle),
                       parser.GetFontName(m_textStyle),
                       parser.GetFontEncoding()));
 }
@@ -253,6 +258,8 @@ bool TextCell::IsOperator()
 wxString TextCell::ToString(bool all)
 {
   wxString text = m_text;
+  if (m_textStyle == TS_STRING)
+    text = wxT("\"") + text + wxT("\"");
   return text + MathCell::ToString(all);
 }
 
@@ -264,12 +271,38 @@ wxString TextCell::ToTeX(bool all)
   else if (m_textStyle == TS_GREEK_CONSTANT)
   {
     if (m_text[0] != '%')
-      text = wxT("\\") + m_text;
+      text = wxT("%") + m_text;
     else
-    {
       text = m_text;
-      text.Replace(wxT("%"), wxT("\\"));
-    }
+
+    if (text == wxT("%Alpha"))
+      text = wxT("A");
+    else if (text == wxT("%Beta"))
+      text = wxT("B");
+    else if (text == wxT("%Epsilon"))
+      text = wxT("E");
+    else if (text == wxT("%Zeta"))
+      text = wxT("Z");
+    else if (text == wxT("%Eta"))
+      text = wxT("H");
+    else if (text == wxT("%Iota"))
+      text = wxT("I");
+    else if (text == wxT("%Kappa"))
+      text = wxT("K");
+    else if (text == wxT("%Mu"))
+      text = wxT("M");
+    else if (text == wxT("%Nu"))
+      text = wxT("N");
+    else if (text == wxT("%Omicron"))
+      text = wxT("O");
+    else if (text == wxT("%Rho"))
+      text = wxT("P");
+    else if (text == wxT("%Tau"))
+      text = wxT("T");
+    else if (text == wxT("%Chi"))
+      text = wxT("X");
+    else
+      text = wxT("\\") + text.Mid(1);
   }
   else if (m_textStyle == TS_SPECIAL_CONSTANT)
   {
@@ -291,8 +324,10 @@ wxString TextCell::ToTeX(bool all)
   }
   else
   {
-    text = m_text;
-    text.Replace(wxT("\\"), wxT("\\\\"));
+    if (m_textStyle == TS_FUNCTION)
+      text = wxT("\\mathrm{") + m_text + wxT("}");
+    else
+      text = m_text;
     text.Replace(wxT("^"), wxT("\\^"));
     text.Replace(wxT("_"), wxT("\\_"));
     text.Replace(wxT("%"), wxT("\\%"));
@@ -363,6 +398,8 @@ void TextCell::SetAltText()
     {
       if (m_text == wxT("+") || m_text == wxT("-") || m_text == wxT("="))
         m_texFontname = wxT("jsMath-cmr10");
+      else if (m_text == wxT("%pi"))
+        m_texFontname = wxT("jsMath-cmmi10");
       else
         m_texFontname = wxT("jsMath-cmsy10");
       m_altJs = true;
@@ -506,6 +543,8 @@ wxString TextCell::GetSymbolUnicode()
     return wxT("=");
   else if (m_text == wxT("inf"))
     return wxString(L"\x221E");
+  else if (m_text == wxT("%pi"))
+    return wxString(L"\x03C0");
   else if (m_text == wxT("<="))
     return wxString(L"\x2264");
   else if (m_text == wxT(">="))
@@ -528,9 +567,10 @@ wxString TextCell::GetSymbolUnicode()
     return wxString(L"\x00AC");
   else if (m_text == wxT("->"))
     return wxString(L"\x2192");
+ /*
   else if (m_textStyle == TS_SPECIAL_CONSTANT && m_text == wxT("d"))
     return wxString(L"\x2202");
-
+  */
   return wxEmptyString;
 }
 
@@ -653,6 +693,8 @@ wxString TextCell::GetSymbolSymbol()
 {
   if (m_text == wxT("inf"))
     return wxT("\xA5");
+  else if (m_text == wxT("%pi"))
+    return wxT("\x70");
   else if (m_text == wxT("->"))
     return wxT("\xAE");
   else if (m_text == wxT(">="))
@@ -802,6 +844,8 @@ wxString TextCell::GetSymbolTeX()
     return wxT("+");
   else if (m_text == wxT("-"))
     return wxT("\x7B");
+  else if (m_text == wxT("%pi"))
+    return wxT("\xD9");
   else if (m_text == wxT("="))
     return wxT("=");
   else if (m_text == wxT("->"))
